@@ -391,6 +391,16 @@ DeviceSyncResultPtr ApiRequestPrivate::deviceSynchronizationStatus ( const QStri
     return result;
 }
 
+DeviceSyncResultPtr ApiRequestPrivate::setDeviceSynchronizationStatus(const QString& username, const QList< QStringList >& synchronize, const QList< QString >& stopSynchronize )
+{
+    QString requestUrl = UrlBuilder::getDeviceSynchronizationStatusUrl( username );
+    QNetworkReply* reply;
+    QByteArray data = JsonCreator::deviceSynchronizationListsToJSON( synchronize, stopSynchronize );
+    reply = m_requestHandler.postRequest( data, requestUrl );
+    DeviceSyncResultPtr result( new DeviceSyncResult( reply ) );
+    return result;
+}
+
 ApiRequest::ApiRequest( const QString& username, const QString& password, QNetworkAccessManager* nam ) : d( new ApiRequestPrivate( username, password, nam ) )
 {
 }
@@ -598,3 +608,8 @@ DeviceSyncResultPtr ApiRequest::deviceSynchronizationStatus ( const QString& use
 {
     return d->deviceSynchronizationStatus( username );
 }
+
+DeviceSyncResultPtr ApiRequest::setDeviceSynchronizationStatus(const QString& username, const QList<QStringList>& synchronize, const QList<QString>& stopSynchronize )
+{
+    return d->setDeviceSynchronizationStatus( username, synchronize, stopSynchronize );
+}
