@@ -20,8 +20,8 @@
 * USA                                                                      *
 ***************************************************************************/
 
-#ifndef APIREQUEST_H
-#define APIREQUEST_H
+#ifndef LIBMYGPO_QT_APIREQUEST_H
+#define LIBMYGPO_QT_APIREQUEST_H
 
 #define MYGPO_MAJOR_VERSION 1
 #define MYGPO_MINOR_VERSION 0
@@ -395,6 +395,8 @@ public:
 
     DeviceSyncResultPtr deviceSynchronizationStatus( const QString& username );
 
+    DeviceSyncResultPtr setDeviceSynchronizationStatus( const QString& username, const QList<QStringList>& synchronize, const QList<QString>& stopSynchronize );
+
 private:
     ApiRequestPrivate* const d;
 };
