@@ -20,8 +20,8 @@
 * USA                                                                      *
 ***************************************************************************/
 
-#ifndef EPISODEACTION_H
-#define EPISODEACTION_H
+#ifndef LIBMYGPO_QT_EPISODEACTION_H
+#define LIBMYGPO_QT_EPISODEACTION_H
 
 #include <QUrl>
 #include <QString>
@@ -52,6 +52,8 @@ public:
     enum ActionType { Download, Play, Delete, New };
     EpisodeAction( const QVariant& variant, QObject* parent = 0 );
     EpisodeAction( const QUrl& podcastUrl, const QUrl& episodeUrl, const QString& deviceName, EpisodeAction::ActionType action, qulonglong timestamp, qulonglong started, qulonglong position, qulonglong total, QObject* parent = 0 );
+    EpisodeAction( const QUrl& podcastUrl, const QUrl& episodeUrl, const QString& deviceName, EpisodeAction::ActionType action, qulonglong timestamp, qulonglong position, QObject* parent = 0 );
+    EpisodeAction( const QUrl& podcastUrl, const QUrl& episodeUrl, const QString& deviceName, EpisodeAction::ActionType action, qulonglong timestamp, QObject* parent = 0 );
     virtual ~EpisodeAction();
 
     QUrl podcastUrl() const;
@@ -75,4 +77,4 @@ typedef QSharedPointer<EpisodeAction> EpisodeActionPtr;
 
 Q_DECLARE_METATYPE( mygpo::EpisodeActionPtr );
 
-#endif // EPISODEACTION_H
+#endif // LIBMYGPO_QT_EPISODEACTION_H
